/**
 * Filename    : ParseMessage.h
 * Description : Stores error message encountered during an SBML parse
 * Author(s)   : SBML Development Group <sbml-team@caltech.edu>
 * Organization: JST ERATO Kitano Symbiotic Systems Project
 * Created     : 2002-04-16
 * Revision    : $Id: ParseMessage.hpp,v 1.3 2004/08/19 02:06:37 bbornstein Exp $
 * Source      : $Source: /cvsroot/sbml/libsbml/src/sbml/ParseMessage.hpp,v $
 *
 * Copyright 2002 California Institute of Technology and
 * Japan Science and Technology Corporation.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY, WITHOUT EVEN THE IMPLIED WARRANTY OF
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  The software and
 * documentation provided hereunder is on an "as is" basis, and the
 * California Institute of Technology and Japan Science and Technology
 * Corporation have no obligations to provide maintenance, support,
 * updates, enhancements or modifications.  In no event shall the
 * California Institute of Technology or the Japan Science and Technology
 * Corporation be liable to any party for direct, indirect, special,
 * incidental or consequential damages, including lost profits, arising
 * out of the use of this software and its documentation, even if the
 * California Institute of Technology and/or Japan Science and Technology
 * Corporation have been advised of the possibility of such damage.  See
 * the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * The original code contained here was initially developed by:
 *
 *     Ben Bornstein
 *     The Systems Biology Markup Language Development Group
 *     ERATO Kitano Symbiotic Systems Project
 *     Control and Dynamical Systems, MC 107-81
 *     California Institute of Technology
 *     Pasadena, CA, 91125, USA
 *
 *     http://www.cds.caltech.edu/erato
 *     mailto:sbml-team@caltech.edu
 *
 * Contributor(s):
 */


#ifndef ParseMessage_hpp
#define ParseMessage_hpp


#include <string>


class ParseMessage
{
public:

  LIBSBML_EXTERN
  ParseMessage
  (
      const std::string& message = ""
    , unsigned int       line    = 0
    , unsigned int       col     = 0
  );

  virtual ~ParseMessage ();


  LIBSBML_EXTERN const std::string& getMessage () const;
  LIBSBML_EXTERN unsigned int       getLine    () const;
  LIBSBML_EXTERN unsigned int       getColumn  () const;


protected:

  std::string  message;

  unsigned int line;
  unsigned int column;
};



#endif  // ParseMessage_hpp
